@@ -1,26 +1,21 @@
-from nonebot.typing import T_State
+from argparse import Namespace
+
 from nonebot.matcher import Matcher
+from nonebot.params import ShellCommandArgs
 from nonebot.message import run_preprocessor
 from nonebot.exception import IgnoredException
 from nonebot.plugin import on_shell_command, get_loaded_plugins
-from nonebot.adapters.cqhttp import (
-    Bot,
-    Event,
-    MessageEvent,
-    GroupMessageEvent,
-)
+from nonebot.adapters.onebot.v11 import Bot, Event, MessageEvent, GroupMessageEvent
 
-from .parser import npm_parser
-from .manager import PluginManager
 from .handle import Handle
+from .parser import npm_parser
+from .manager import plugin_manager
 
 npm = on_shell_command("npm", parser=npm_parser, priority=1)
 
 # 在 Matcher 运行前检测其是否启用
 @run_preprocessor
-async def _(matcher: Matcher, bot: Bot, event: Event, state: T_State):
-
-    plugin_manager = PluginManager()
+async def _(matcher: Matcher, bot: Bot, event: Event):
     plugin = matcher.plugin_name
 
     conv = {
@@ -48,8 +43,7 @@ async def _(matcher: Matcher, bot: Bot, event: Event, state: T_State):
 
 
 @npm.handle()
-async def _(bot: Bot, event: MessageEvent, state: T_State):
-    args = state["args"]
+async def _(bot: Bot, event: MessageEvent, args: Namespace = ShellCommandArgs()):
     args.conv = {
         "user": [event.user_id],
         "group": [event.group_id] if isinstance(event, GroupMessageEvent) else [],
